summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqpopupmenu.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
commitd296f1d337dabfeae5191955fdadb874965dbbe9 (patch)
tree1a4b3b4cca01f2ea77eee2497297219d60e9bbd4 /tqtinterface/qt4/src/widgets/tqpopupmenu.h
parenteaa7ee2e0bbca40ba3173c4304f81957e8964291 (diff)
downloadexperimental-d296f1d337dabfeae5191955fdadb874965dbbe9.tar.gz
experimental-d296f1d337dabfeae5191955fdadb874965dbbe9.zip
rename the following methods:
tqparent parent tqmask mask
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqpopupmenu.h')
-rw-r--r--tqtinterface/qt4/src/widgets/tqpopupmenu.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqpopupmenu.h b/tqtinterface/qt4/src/widgets/tqpopupmenu.h
index 8863cd5..d7290f4 100644
--- a/tqtinterface/qt4/src/widgets/tqpopupmenu.h
+++ b/tqtinterface/qt4/src/widgets/tqpopupmenu.h
@@ -55,7 +55,7 @@ class TQ_EXPORT TQPopupMenu : public TQFrame, public TQMenuData
TQ_OBJECT
Q_PROPERTY( bool checkable READ isCheckable WRITE setCheckable )
public:
- TQPopupMenu( TQWidget* tqparent=0, const char* name=0 );
+ TQPopupMenu( TQWidget* parent=0, const char* name=0 );
~TQPopupMenu();
void popup( const TQPoint & pos, int indexAtPoint = -1 ); // open
@@ -88,7 +88,7 @@ public:
Q_SIGNALS:
void activated( int itemId );
void highlighted( int itemId );
- void activatedRedirect( int itemId ); // to tqparent menu
+ void activatedRedirect( int itemId ); // to parent menu
void highlightedRedirect( int itemId );
void aboutToShow();
void aboutToHide();